# AIM SERVER
AIM_SERVER_DEFAULT_PORT = 53800
AIM_SERVER_DEFAULT_HOST = '0.0.0.0'
AIM_SERVER_MOUNTED_REPO_PATH = '__AIM_SERVER_MOUNT_REPO_PATH__'

# AIM CLIENT
# The path of the PEM-encoded root certificates. Used for secure channel establishment
AIM_CLIENT_SSL_CERTIFICATES_FILE = '__AIM_CLIENT_SSL_CERTIFICATES_FILE__'
